/*
 * Copyright (c) 2023 - 2024. KeyWare.Co.Ltd All rights reserved.
 * 项目名称：28所 C++ 信息安全性设计准则
 * 项目描述：用于检查C++源代码的安全性设计准则的Sonarqube插件
 * 版权说明：本软件属北京关键科技股份有限公司所有，在未获得北京关键科技股份有限公司正式授权情况下，任何企业和个人，不能获取、阅读、安装、传播本软件涉及的任何受知识产权保护的内容。
 */
package com.keyware.sonar.cxx;

import org.sonar.api.resources.Language;
import org.sonar.api.scanner.ScannerSide;
import org.sonar.api.server.rule.RulesDefinition;
import org.sonar.cxx.squidbridge.annotations.AnnotationBasedRulesDefinition;

import java.util.Arrays;

/**
 *
 * @author jocs
 */
@ScannerSide
public abstract class CustomCxxRulesDefinition implements RulesDefinition {

  @Override
  public void define(Context context) {
    var repo = context.createRepository(repositoryKey(), getLanguage().getKey())
      .setName(repositoryName());

    // Load metadata from check classes' annotations
    new AnnotationBasedRulesDefinition(repo, getLanguage().getKey()).addRuleClasses(false,
                                                                                    Arrays.asList(checkClasses()));

    repo.done();
  }

  /**
   * Name of the custom rule repository.
   *
   * @return
   */
  public abstract Language getLanguage();

  /**
   * Name of the custom rule repository.
   *
   * @return
   */
  public abstract String repositoryName();

  /**
   * Key of the custom rule repository.
   *
   * @return
   */
  public abstract String repositoryKey();

  /**
   * Array of the custom rules classes.
   */
  @SuppressWarnings("rawtypes")
  public abstract Class[] checkClasses();

}
