/*
 * Copyright (c) 2023 - 2024. KeyWare.Co.Ltd All rights reserved.
 * 项目名称：C++ 信息安全性设计准则
 * 项目描述：用于检查C++源代码的安全性设计准则的Sonarqube插件
 * 版权说明：本软件属北京关键科技股份有限公司所有，在未获得北京关键科技股份有限公司正式授权情况下，任何企业和个人，不能获取、阅读、安装、传播本软件涉及的任何受知识产权保护的内容。
 */
package com.keyware.sonar.cxx.rules;

import com.keyware.sonar.cxx.CxxLanguage;
import com.keyware.sonar.cxx.rules.checkers.ABCVarNameChecker;
import org.sonar.api.server.rule.RulesDefinition;
import org.sonar.cxx.squidbridge.annotations.AnnotationBasedRulesDefinition;

import java.util.Arrays;
import java.util.List;

/**
 * 信息安全性设计准则规则仓库定义实现类
 *
 * @author GuoXin
 * @date 2024/1/9
 */
public class SecurityDesignRuleRepository implements RulesDefinition {
    public final static String REPOSITORY_KEY = "cxx-security-design-rules";
    public final static String REPOSITORY_NAME = "C++信息安全性设计准则";

    // 规则检查器的集合，当有新的规则开发完毕后，需要添加到下面的集合中
    public final static List<Class> RULE_CHECKERS = Arrays.asList(ABCVarNameChecker.class);

    @Override
    public void define(Context context) {
        var repository = context.createRepository(REPOSITORY_KEY, CxxLanguage.KEY).
                setName(REPOSITORY_NAME);
        new AnnotationBasedRulesDefinition(repository, CxxLanguage.KEY).addRuleClasses(false, RULE_CHECKERS);
        repository.done();
    }
}
